nemSym: Generating symmetric networks according to the selected local network mechanisms
Description
It generates random network considering the selected local network mechanisms.
Usage
nemSym(X, formula, theta, k = 5000, q)
Value
The list with the following elements:
initialNetwork - Initial network; of class matrix.
finalNetwork - Final (generated) network; of class matrix.
formula - The list of functions that define mechanisms used.
theta - A vector with the mechanisms' weights/strengths used.
k - The number of iterations.
q - The probability of establishing a link.
Arguments
X
Initial network; of class matrix.
formula
The list of local netork mechanisms to be considered.
theta
A vector with the mechanisms' weights/strengths.
k
The number of iterations.
q
The probability of establishing a link (i.e. expected/desired density).
Author
Marjan Cugmas and Aleš Žiberna
References
Cugmas, M., DeLay, D., Žiberna, A., & Ferligoj, A. (2020). Symmetric core-cohesive blockmodel in preschool children’s interaction networks. PloS one, 15(1), e0226801.