powered by
Calculate the normalized network statistic according to the popularity mechanism.
popularity(X, actor = NULL)
A vector with the normalized popularity mechanism, cacluated for each unit.
Binary network; of class matrix.
matrix
Not used by the function, set to NULL. Necessary for using within other functions, e.g. nemBM.
NULL
Marjan Cugmas and Aleš Žiberna
Cugmas, M., & Žiberna, A. (2022). Approaches to blockmodeling dynamic networks: a Monte Carlo simulation study. Social Networks, in print.
X <- matrix(sample(c(0,1), size = 9**2, replace = TRUE), nrow = 9) popularity(X)
Run the code above in your browser using DataLab