powered by
Calculates the network statistic according to the outgoing shared partners mechanism.
OSPtransitivity(X, actor)
A vector with the number of paths of length two between the actor and other units.
Binary network; of class matrix.
matrix
A unit (actor; row/column number), which have an opportunity to change a link.
Marjan Cugmas and Aleš Žiberna
Cugmas, M., & Žiberna, A. (2022). Approaches to blockmodeling dynamic networks: a Monte Carlo simulation study. Social Networks, in review.
X <- matrix(sample(c(0,1), size = 9**2, replace = TRUE), nrow = 9) OSPtransitivity(X, actor = 2)
Run the code above in your browser using DataLab