Calculate the normalized network statistic according to the assortativity mechanism.
Usage
assortativity(X, actor)
Value
A vector with the assortativity mechanism, cacluated between the actor and other units.
Arguments
X
Binary network; of class matrix.
actor
A unit (actor; row/column number), which have an opportunity to change a link.
Author
Marjan Cugmas and Aleš Žiberna
Details
The function returns the value 1 when actor (i.e. ego) and alter do not differ in the number of incoming ties.
Otherwise, lower values indicate higher difference in the number of incoming ties between the actor and alter.
References
Cugmas, M., & Žiberna, A. (2022). Approaches to blockmodeling dynamic networks: a Monte Carlo simulation study. Social Networks, in print