Calculate the normalized network statistic according to the mutuality mechanism.
Usage
mutuality(X, actor)
Value
A vector with the normalized mutuality mechanism, cacluated between the actor and other units.
Arguments
X
Binary network; of class matrix.
actor
A unit (actor; row/column number), which have an opportunity to change a link.
Author
Marjan Cugmas and Aleš Žiberna
References
Cugmas, M., Žiberna, A., & Ferligoj, A. (2019). Mechanisms generating asymmetric core-cohesive blockmodels. Advances in Methodology and Statistics, 16(1), 17-41.
Cugmas, M., & Žiberna, A. (2022). Approaches to blockmodeling dynamic networks: a Monte Carlo simulation study. Social Networks, in print.